==> cdktf-provider-google-13.1.0-sources.jar: com/hashicorp/cdktf/providers/google/gke_hub_feature_membership/GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent.java <==
package com.hashicorp.cdktf.providers.google.gke_hub_feature_membership;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-17T04:17:41.960Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.gkeHubFeatureMembership.GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent")
@software.amazon.jsii.Jsii.Proxy(GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent extends software.amazon.jsii.JsiiSerializable {

    /**
     * template_library block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/gke_hub_feature_membership#template_library GkeHubFeatureMembership#template_library}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.gke_hub_feature_membership.GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContentTemplateLibrary getTemplateLibrary() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent> {
        com.hashicorp.cdktf.providers.google.gke_hub_feature_membership.GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContentTemplateLibrary templateLibrary;

        /**
         * Sets the value of {@link GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent#getTemplateLibrary}
         * @param templateLibrary template_library block.
         *                        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.12.0/docs/resources/gke_hub_feature_membership#template_library GkeHubFeatureMembership#template_library}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder templateLibrary(com.hashicorp.cdktf.providers.google.gke_hub_feature_membership.GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContentTemplateLibrary templateLibrary) {
            this.templateLibrary = templateLibrary;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent {
        private final com.hashicorp.cdktf.providers.google.gke_hub_feature_membership.GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContentTemplateLibrary templateLibrary;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.templateLibrary = software.amazon.jsii.Kernel.get(this, "templateLibrary", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.gke_hub_feature_membership.GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContentTemplateLibrary.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.templateLibrary = builder.templateLibrary;
        }

        @Override
        public final com.hashicorp.cdktf.providers.google.gke_hub_feature_membership.GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContentTemplateLibrary getTemplateLibrary() {
            return this.templateLibrary;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getTemplateLibrary() != null) {
                data.set("templateLibrary", om.valueToTree(this.getTemplateLibrary()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.gkeHubFeatureMembership.GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent.Jsii$Proxy that = (GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent.Jsii$Proxy) o;

            return this.templateLibrary != null ? this.templateLibrary.equals(that.templateLibrary) : that.templateLibrary == null;
        }

        @Override
        public final int hashCode() {
            int result = this.templateLibrary != null ? this.templateLibrary.hashCode() : 0;
            return result;
        }
    }
}

==> cdktf-provider-google-13.13.0-sources.jar: com/hashicorp/cdktf/providers/google/gke_hub_feature_membership/GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent.java <==
package com.hashicorp.cdktf.providers.google.gke_hub_feature_membership;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.96.0 (build 921e240)", date = "2024-04-09T03:36:16.047Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.gkeHubFeatureMembership.GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent")
@software.amazon.jsii.Jsii.Proxy(GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent extends software.amazon.jsii.JsiiSerializable {

    /**
     * bundles block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/gke_hub_feature_membership#bundles GkeHubFeatureMembership#bundles}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getBundles() {
        return null;
    }

    /**
     * template_library block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/gke_hub_feature_membership#template_library GkeHubFeatureMembership#template_library}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.gke_hub_feature_membership.GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContentTemplateLibrary getTemplateLibrary() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent> {
        java.lang.Object bundles;
        com.hashicorp.cdktf.providers.google.gke_hub_feature_membership.GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContentTemplateLibrary templateLibrary;

        /**
         * Sets the value of {@link GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent#getBundles}
         * @param bundles bundles block.
         *                Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/gke_hub_feature_membership#bundles GkeHubFeatureMembership#bundles}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder bundles(com.hashicorp.cdktf.IResolvable bundles) {
            this.bundles = bundles;
            return this;
        }

        /**
         * Sets the value of {@link GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent#getBundles}
         * @param bundles bundles block.
         *                Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/gke_hub_feature_membership#bundles GkeHubFeatureMembership#bundles}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder bundles(java.util.List<? extends com.hashicorp.cdktf.providers.google.gke_hub_feature_membership.GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContentBundles> bundles) {
            this.bundles = bundles;
            return this;
        }

        /**
         * Sets the value of {@link GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent#getTemplateLibrary}
         * @param templateLibrary template_library block.
         *                        Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google/5.24.0/docs/resources/gke_hub_feature_membership#template_library GkeHubFeatureMembership#template_library}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder templateLibrary(com.hashicorp.cdktf.providers.google.gke_hub_feature_membership.GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContentTemplateLibrary templateLibrary) {
            this.templateLibrary = templateLibrary;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent {
        private final java.lang.Object bundles;
        private final com.hashicorp.cdktf.providers.google.gke_hub_feature_membership.GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContentTemplateLibrary templateLibrary;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.bundles = software.amazon.jsii.Kernel.get(this, "bundles", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.templateLibrary = software.amazon.jsii.Kernel.get(this, "templateLibrary", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.gke_hub_feature_membership.GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContentTemplateLibrary.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.bundles = builder.bundles;
            this.templateLibrary = builder.templateLibrary;
        }

        @Override
        public final java.lang.Object getBundles() {
            return this.bundles;
        }

        @Override
        public final com.hashicorp.cdktf.providers.google.gke_hub_feature_membership.GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContentTemplateLibrary getTemplateLibrary() {
            return this.templateLibrary;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getBundles() != null) {
                data.set("bundles", om.valueToTree(this.getBundles()));
            }
            if (this.getTemplateLibrary() != null) {
                data.set("templateLibrary", om.valueToTree(this.getTemplateLibrary()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.gkeHubFeatureMembership.GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent.Jsii$Proxy that = (GkeHubFeatureMembershipPolicycontrollerPolicyControllerHubConfigPolicyContent.Jsii$Proxy) o;

            if (this.bundles != null ? !this.bundles.equals(that.bundles) : that.bundles != null) return false;
            return this.templateLibrary != null ? this.templateLibrary.equals(that.templateLibrary) : that.templateLibrary == null;
        }

        @Override
        public final int hashCode() {
            int result = this.bundles != null ? this.bundles.hashCode() : 0;
            result = 31 * result + (this.templateLibrary != null ? this.templateLibrary.hashCode() : 0);
            return result;
        }
    }
}
